@@ -9,7 +9,7 @@ use Readonly;
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
@@ -24,8 +24,9 @@ sub print {
 
 	my $item;
 	if (exists $opts_hr->{'cb'}) {
-		$item = $opts_hr->{'cb'}->get('label', $obj->value) || $obj->value;
-	} else {
+		$item = $opts_hr->{'cb'}->get('label', $obj->value);
+	}
+	if (! defined $item) {
 		$item = $obj->value;
 	}
 
@@ -125,6 +126,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
